@@ -5,7 +5,7 @@ op.edibble <- list(
   edibble.tree.decorate.levels = function(x) cli::col_grey(cli::pluralize("({x} level{?s})")),
   edibble.tree.decorate.title = cli::combine_ansi_styles("cyan", "italic"),
   # vector labels
-  edibble.levels.label.leading_zero = FALSE,
+  edibble.levels.label.leading_zero = TRUE,
   edibble.levels.label.min_ndigits = 0,
   edibble.levels.label.sep = ""
 )
